require 'rho/rhocontroller'
require 'helpers/browser_helper'
require 'lib/authenticated'
require 'lib/rosp_http'
require 'json'


class CategoryController < Rho::RhoController
  include BrowserHelper
  include Authenticated
  include RospHttp::Callback
  # GET /Category
  def index
    http = RospHttp.connect(
      :method => "get",
      :url => "#{Component.server_address}/categories.json",
      :back_url => url_for(:action => :index),
      :controller => self
    )
    @categories = http["body"]
    render :back => url_for(:controller => :Session, :action => :index)
  end

  # GET /Category/{1}
  def show
    http = RospHttp.connect(
      :method => "get",
      :url =>  "#{Component.server_address}/categories/#{strip_braces(@params["id"])}.json",
      :back_url => url_for(:action => :show),
      :controller => self
    )    
    @category = http["body"]["parent"]
    @children = http["body"]["children"]
    if @category["parent_id"] == 0
      render :back => url_for(:action => :index)
    else
      render :back => url_for(:action => :show, :id => @category["parent_id"])
    end
  end

  # GET /Category/new
  def new
    @parent_id = strip_braces(@params["id"])
    if @parent_id == "0"
      @back_url = url_for(:action => :index)
    else
      @back_url = url_for(:action => :show, :id => @parent_id)
    end
    render :back => @back_url
  end

  # GET /Category/{1}/edit
  def edit
    http = RospHttp.connect(
      :method => "get",
      :url =>  "#{Component.server_address}/categories/#{strip_braces(@params["id"])}.json",
      :back_url => url_for(:action => :show),
      :controller => self
    )    
    @category = http["body"]["parent"]
    if @category
      render :action => :edit, :back => url_for(:action => :index)
    else
      redirect :action => :index
    end
  end

  # POST /Category/create
  def create
    json = ::JSON.generate(@params["category"])
    http = RospHttp.connect(
      :method => "post",
      :url => "#{Component.server_address}/categories.json",
      :body => "category=#{json}",
      :back_url => url_for(:action => :new),
      :controller => self)
    if http["body"] == "NG"
      Alert.show_popup("データの作成に失敗しました。")
    end
    redirect :action => :index
  end

  # POST /Category/{1}/update
  def update
    json = ::JSON.generate(@params["category"])
    http = RospHttp.connect(
      :method => "post",
      :http_command => "PUT",
      :url => "#{Component.server_address}/categories/#{strip_braces(@params["id"])}.json",
      :body => "category=#{json}",
      :back_url => url_for(:action => :edit, :id => strip_braces(@params["id"])),
      :controller => self)
    if http["body"] == "NG"
      Alert.show_popup("データの更新に失敗しました。")
    end
    redirect :action => :index
  end

  # POST /Category/{1}/delete
  def delete
     http = RospHttp.connect(
      :method => "post",
      :http_command => "DELETE",
      :url => "#{Component.server_address}/categories/#{strip_braces(@params["id"])}.json",
      :back_url => url_for(:action => :edit, :id => strip_braces(@params["id"])),
      :controller => self)
    if http["body"] == "NG"
      Alert.show_popup("データの削除に失敗しました。")
    end
    redirect :action => :index  
  end
end
